#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 17/11/2009
#
# package			: transcode
# homepage			: http://www.transcoding.org/cgi-bin/transcode
# source location	: http://download.berlios.de/tcforge/transcode-1.1.5.tar.bz2
# dependency        : lame,ffmpeg,faac,faad2,a52dec,xvidcore,libogg,libtheora,libdvdread,libxml2,sdl

softname='transcode'
softversion='1.1.5'
packageversion='64.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://prdownload.berlios.de/tcforge/$softname-$softversion.tar.bz2

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
         |-----handy-ruler------------------------------------------------------|
transcode: Transcoding - utilities for transcoding video and audio codecs
transcode:
transcode: Transcode is a suite of command line utilities for transcoding   
transcode: video and audio codecs, and for converting beween different 
transcode: container formats. Transcode can decode and encode many audio 
transcode: and video formats: * MPEG-1/2
transcode:                    * MPEG-4(-part 3) (also DivX and XviD variants)
transcode:                    * Quicktime / MPEG-PS (dvd) (decode only)
transcode:                    * MPEG-1-layer-1/2/3 audio
transcode:                    * AC3 audio 
transcode:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xjvf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--enable-v4l \
	--enable-oss \
	--disable-nuv \
	--enable-libpostproc \
	--enable-freetype2 \
	--enable-lame="yes" \
	--enable-xvid="yes" \
	--enable-x264="yes" \
	--enable-ogg="yes" \
	--enable-vorbis="yes" \
	--enable-theora="yes" \
	--enable-lzo="no" \
	--enable-a52="yes" \
	--enable-faac="yes" \
	--enable-libdv="yes" \
	--enable-libxml2="yes" \
	--enable-mjpegtools="yes" \
	--enable-libquicktime="yes" \
	--enable-libv4l2="yes" \
	--enable-libmpeg2="yes" \
	--enable-sdl="yes" \
	--enable-imagemagick="yes" \
	--build=$arch-slackware-linux || exit

#
# "faire" le package package
#
make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
make install DESTDIR=$dest
   
#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL README STYLE TODO\
      $dest/usr/doc/$softname-$softversion
	mv $dest/usr/share/doc/$softname/html $dest/usr/doc/$softname-$softversion
	mv $dest/usr/share/doc/$softname/release-notes $dest/usr/doc/$softname-$softversion
	cp $dest/usr/share/doc/$softname/*.* $dest/usr/doc/$softname-$softversion
	rm -rf $dest/usr/share
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man/man1
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.txz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.txz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "a52dec,bzip2,cxxlibs|gcc-g++,dirac,e2fsprogs,faac,ffmpeg,\
freetype,gcc,imagemagick,lame,libICE,libSM,libX11,libXau,libXdmcp,libXext,\
libXmu,libXpm,libXt,libXv,libdv,libdvdread,libjpeg,libogg,\
liboil,libquicktime,libtheora,libvorbis,libxcb,libxml2,mjpegtools,mpeg2dec,\
schroedinger,sdl,speex,x264,xvidcore,zlib" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/ap/transcode/source/build-transcode.sh > $package.src
echo $source >> $package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
